pub enum PartReferenceField {
Id,
CreateDate,
}Expand description
Represents the fields for a PartReference object.
A PartReference is typically a lightweight link to a story part,
often found within a list of parts in a story object.
Variants
Id
The unique numerical identifier of the story part.
CreateDate
The timestamp when the part was created.